import 'package:flutter/material.dart';


// ignore: must_be_immutable
class HMButton extends StatelessWidget {
   /// Action when the button is being pressed
  final Function onPressed;

  /// The child of the button, usually Icon+Text, Text, Loading+Text.
  final Widget child;

  /// Width of the button
  late double? width;

  /// Height of the button
  late double? height;

  /// Text color of the button, default is HarmonyOS Blue.
  late Color textColor;

  /// Border radius of the button, default is 25.
  late double borderRadius;

  /// Center the child.
  late bool center;
  /// isDanger - show Color as red or not.
  late bool isDanger;
  /// Normal button following HarmonyOS Design Language
  /// 
  /// Usually used in [Dialog]s([showHMDialog]), and [HMAbility]
  HMButton({
    Key? key,
    required this.onPressed,
    required this.child,
    this.width,
    this.height,
    this.textColor = const Color.fromARGB(255, 10, 89, 247),
    this.borderRadius = 25,
    this.center = false,
    this.isDanger = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: height,
      width: width,
      child: Material(
        textStyle: TextStyle(
            color: isDanger ? const Color.fromARGB(255, 232, 64, 38):textColor,
            fontWeight: FontWeight.w500),
        color: Colors.black.withOpacity(0.05),
        shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(borderRadius)),
        child: InkWell(
          onTap: () => onPressed(),
          splashColor: const Color.fromARGB(0, 255, 94, 94),
          child: Padding(
            padding: const EdgeInsets.all(13.0),
            child: center ? Center(child: child,) : child,
          ),
          borderRadius: BorderRadius.circular(borderRadius),
        ),
      ),
    );
  }
}
