import 'package:flutter/material.dart';

// ignore: must_be_immutable
/// Elevated Button following HarmonyOS Design Language
/// 
/// Can be used in primary options in [Dialog]([showHMDialog]) and some button in [HMAbility]
// ignore: must_be_immutable
class HMElevatedButton extends StatelessWidget {
   /// Action when the button is being pressed
  final Function onPressed;

  /// The child of the button, usually Icon+Text, Text, Loading+Text.
  final Widget child;

  /// Width of the button
  late double? width;

  /// Height of the button
  late double? height;

  /// Text color of the button, default is White.
  late Color textColor;

  /// Border radius of the button, default is 25.
  late double borderRadius;

  /// Center the child.
  late bool center;
  HMElevatedButton({
    Key? key,
    required this.onPressed,
    required this.child,
    this.width,
    this.height,
    this.textColor = Colors.white,
    this.borderRadius = 25,
    this.center = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: width,
      height: height,
      child: Material(
        textStyle: TextStyle(
            color: textColor,
            fontWeight: FontWeight.w500),
        color: const Color(0xFF0A59F7),
        shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(borderRadius)),
        child: InkWell(
          onTap: () => onPressed(),
          splashColor: const Color.fromARGB(0, 255, 94, 94),
          child: Padding(
            padding: const EdgeInsets.all(13.0),
            child: center ? Center(child: child,) : child,
          ),
          borderRadius: BorderRadius.circular(borderRadius),
        ),
      ),
    );
  }
}
