import 'package:flutter/material.dart';

// ignore: must_be_immutable
class HMIconButton extends StatelessWidget {
   /// Action when the button is being pressed
  final Function onPressed;

  /// The [Icon]
  final Icon icon;

  /// Width of the button
  late double? width;

  /// Height of the button
  late double? height;

  /// Not usable, leftover
  late Color textColor;

  /// Border radius of the button, default is 15.
  late double borderRadius;

  /// Center the child.
  late bool center;

  /// IconButton following HarmonyOS Design
  /// 
  /// Replace [IconButton] of Material Design.
  /// [HMIconButton] is usually used in actions on [HMAbility]
  /// 
  HMIconButton({
    Key? key,
    required this.onPressed,
    required this.icon,
    this.width,
    this.height,
    this.textColor = const Color.fromARGB(255, 10, 89, 247),
    this.borderRadius = 15,
    this.center = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: width,
      height: height,
      child: Material(
        textStyle: TextStyle(
            color: textColor,
            fontWeight: FontWeight.w500),
        color: Colors.transparent,
        shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.circular(borderRadius)),
        child: InkWell(
          onTap: () => onPressed(),
          splashColor: const Color.fromARGB(0, 255, 94, 94),
          child: Padding(
            padding: const EdgeInsets.all(13),
            child: center ? Center(child: icon,) : icon,
          ),
          borderRadius: BorderRadius.circular(borderRadius),
        ),
      ),
    );
  }
}
