import 'package:flutter/material.dart';

class HMAbility extends StatefulWidget {
  /// The content of the page/ability
  final Widget body;

  /// Appbar's title of the ability/page
  final String title;

  /// Optional floating action button(prefer[HMFloatingActionButton]) for the ability/page.
  final Widget? floatingActionButton;

  /// Options on the top right of the screen
  final List<Widget> actions;

  /// Creates a HarmonyOS Ability.
  ///
  /// Replaces [Scaffold], has a big [SliverAppBar] and HarmonyOS background color
  ///
  /// [HMAbility] is an effort to recreate the UI side of HarmonyOS Ability system in flutter,
  /// so the logic will be as similar as possible although the names etc. will still be dart-styled.
  /// to have a truely realistic HarmonyOS-esque looking app, use this widget.
  const HMAbility(
      {Key? key,
      required this.body,
      required this.title,
      this.floatingActionButton,
      this.actions = const []})
      : super(key: key);

  @override
  State<HMAbility> createState() => _HMAbilityState();
}

class _HMAbilityState extends State<HMAbility> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: NestedScrollView(
        physics: const BouncingScrollPhysics(
            parent: AlwaysScrollableScrollPhysics()),
        floatHeaderSlivers: true,
        headerSliverBuilder: (BuildContext context, bool innerBoxIsScrolled) {
          return <Widget>[
            SliverAppBar(
              backgroundColor: const Color.fromARGB(255, 241, 243, 245),
              expandedHeight: 180.0,
              pinned: true,
              elevation: 0,
              stretch: true,
              leading: Container(),
              actions: widget.actions,
              flexibleSpace: FlexibleSpaceBar(
                titlePadding: const EdgeInsets.fromLTRB(10, 0, 10, 20),
                title: Text(
                  widget.title,
                  style: const TextStyle(color: Colors.black, fontSize: 20),
                ),
              ),
            ),
          ];
        },
        body: Container(
            color: const Color.fromARGB(255, 241, 243, 245),
            height: double.infinity,
            width: double.infinity,
            child: widget.body),
      ),
      floatingActionButton: widget.floatingActionButton,
    );
  }
}
