// ignore_for_file: prefer_typing_uninitialized_variables

import 'package:flutter/material.dart';

class HMTextInput extends StatefulWidget {
  /// Placeholder text
  final placeholder;
  /// Controller for the textinput([TextEditingController])
  final controller;
  /// Maximum lines for the input, default is 1.
  final maxLines;
  /// Icon in the prefix
  final prefixIcon;
  /// Is the background HarmonyOS Snow Grey?
  final grey;
  /// Text input following HarmonyOS Design Language
  /// 
  /// Replaces [TextField] in Material Design.
  const HMTextInput(
      {Key? key,
      required this.placeholder,
      this.controller,
      this.maxLines = 1,
      this.prefixIcon,
      this.grey = false})
      : super(key: key);

  @override
  State<HMTextInput> createState() => _HMTextInputState();
}

class _HMTextInputState extends State<HMTextInput> {
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.all(8.0),
      child: SizedBox(
        height: (widget.maxLines == 1) ? 50 : null,
        child: TextField(
          maxLines: widget.maxLines,
          controller: widget.controller,
          decoration: InputDecoration(
            isDense: true,
            prefixIcon: widget.prefixIcon,
              border: OutlineInputBorder(
                  borderSide: BorderSide.none,
                  borderRadius: BorderRadius.circular(35)),
              fillColor: widget.grey ? Colors.black.withOpacity(0.05): Colors.white,
              filled: true,
              focusedBorder: OutlineInputBorder(
                  borderSide: BorderSide.none,
                  borderRadius: BorderRadius.circular(35)),
              iconColor: Colors.black,
              prefixIconColor: Colors.black,
              alignLabelWithHint: true,
              hintStyle: TextStyle(color: Colors.black.withOpacity(0.6)),
              hintText: widget.placeholder),
        ),
      ),
    );
  }
}
